@@ -21,11 +21,18 @@
 # Package Initialization
 #
     package P4::OO::Workspace;
-    our $VERSION = '0.00_01';
+    our $VERSION = '0.00_02';
     use base 'P4::OO::Client';
     use strict;
 
 
+######################################################################
+# Globals
+#
+    # Subclasses must define SPECOBJ_TYPE
+    sub SPECOBJ_TYPE { return( 'workspace' ); }
+
+
 ######################################################################
 #
 # P4::OO::Workspace is just a stub, P4::OO::Client does all the work
